harness_py_sdk.harness_templates API documentation

# harness_py_sdk.harness_templates

class HarnessTemplates(harness_base_service.HarnessBaseService):
def fetch_template_yaml( self, template_identifier, version, org_identifier=None, project_identifier=None):
def fetch_stable_template_yaml( self, template_identifier, org_identifier=None, project_identifier=None):
def create_template_pipeline(self, template_data, org_identifier=None, project_identifier=None):

##### Inherited Members

harness_base_service.HarnessBaseService
  HarnessBaseService
  pipelines
  services
  connectors